==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/hu-HU/auth/message.php <==
<?php

return array(

    'account_already_exists' => 'Már létezik ezzel az e-mail címmel felhasználó.',
    'account_not_found'      => 'A felhasználónév vagy a jelszó érvénytelen.',
    'account_not_activated'  => 'Ez a felhasználó nincs aktiválva.',
    'account_suspended'      => 'Ez a felhasználói fiók fel van függesztve.',
    'account_banned'         => 'Ez a felhasználó ki van tiltva.',
    'throttle'               => 'Túl sok sikertelen bejelentkezési próbálkozás. Próbáld újra :minutes perc múlva.',

    'two_factor' => array(
        'already_enrolled'      => 'Az eszközöd már regisztrálva van.',
        'success'               => 'Sikeresen bejelentkeztél.',
        'code_required'         => 'Kétlépcsős azonosító kód szükséges.',
        'invalid_code'          => 'A kétlépcsős azonosító kód érvénytelen.',
    ),

    'signin' => array(
        'error'   => 'Bejelentkezés közben probléma lépett fel, kérjük próbálja újra.',
        'success' => 'Sikeresen bejelentkezett.',
    ),

    'logout' => array(
        'error'   => 'Probléma merült fel a kijelentkezésed közben, próbáld meg újra.',
        'success' => 'Sikeresen kijelentkeztél.',
    ),

    'signup' => array(
        'error'   => 'Felhasználói fiók létrehozása közben probléma lépett fel, kérjük próbálja újra.',
        'success' => 'A felhasználói fiók sikeresen elkészült.',
    ),

    'forgot-password' => array(
        'error'   => 'A jelszó visszaállító kód kiküldése közben probléma lépett fel, kérjük próbálja újra.',
        'success' => 'Ha az adott email cím létezik a rendszerünkben, abban az esetben elküldtük a jelszó visszaállító linket az adott email címre.',
    ),

    'forgot-password-confirm' => array(
        'error'   => 'Jelszó helyreállítás közben probléma lépett fel, kérjük próbálja újra.',
        'success' => 'A jelszavát sikeresen helyreállította.',
    ),


);

==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/hu-HU/auth/message.php <==
<?php

return array(

    'account_already_exists' => 'Már létezik ezzel az e-mail címmel felhasználó.',
    'account_not_found'      => 'A felhasználónév vagy a jelszó érvénytelen.',
    'account_not_activated'  => 'Ez a felhasználó nincs aktiválva.',
    'account_suspended'      => 'Ez a felhasználói fiók fel van függesztve.',
    'account_banned'         => 'Ez a felhasználó ki van tiltva.',
    'throttle'               => 'Túl sok sikertelen bejelentkezési próbálkozás. Próbáld újra :minutes perc múlva.',

    'two_factor' => array(
        'already_enrolled'      => 'Az eszközöd már regisztrálva van.',
        'success'               => 'Sikeresen bejelentkeztél.',
        'code_required'         => 'Kétlépcsős azonosító kód szükséges.',
        'invalid_code'          => 'A kétlépcsős azonosító kód érvénytelen.',
        'enter_two_factor_code' => 'Kérem, írja be a kétfaktoros hitelesítés kódját.',
        'please_enroll'         => 'Kérem, hogy rendeljen hozzá egy eszközt a kétfaktoros azonosításhoz.',
    ),

    'signin' => array(
        'error'   => 'Bejelentkezés közben probléma lépett fel, kérjük próbálja újra.',
        'success' => 'Sikeresen bejelentkezett.',
    ),

    'logout' => array(
        'error'   => 'Probléma merült fel a kijelentkezésed közben, próbáld meg újra.',
        'success' => 'Sikeresen kijelentkeztél.',
    ),

    'signup' => array(
        'error'   => 'Felhasználói fiók létrehozása közben probléma lépett fel, kérjük próbálja újra.',
        'success' => 'A felhasználói fiók sikeresen elkészült.',
    ),

    'forgot-password' => array(
        'error'   => 'A jelszó visszaállító kód kiküldése közben probléma lépett fel, kérjük próbálja újra.',
        'success' => 'Ha az adott email cím létezik a rendszerünkben, abban az esetben elküldtük a jelszó visszaállító linket az adott email címre.',
    ),

    'forgot-password-confirm' => array(
        'error'   => 'Jelszó helyreállítás közben probléma lépett fel, kérjük próbálja újra.',
        'success' => 'A jelszavát sikeresen helyreállította.',
    ),


);
